@@ -30,11 +30,14 @@ setMethod("[", c("CrunchDataset", "ANY"), function (x, i, ..., drop=FALSE) {
 ##' @rdname dataset-extract
 ##' @export
 setMethod("[", c("CrunchDataset", "character"), function (x, i, ..., drop=FALSE) {
-    w <- match(i, names(x))
+    allnames <- getIndexSlot(allVariables(x), namekey(x)) ## Include hidden
+    w <- match(i, allnames)
     if (any(is.na(w))) {
         halt("Undefined columns selected: ", serialPaste(i[is.na(w)]))
     }
-    callNextMethod(x, w, ..., drop=drop)
+    x@variables <- allVariables(x)[w]
+    readonly(x) <- TRUE ## we don't want to overwrite the big object accidentally
+    return(x)
 })
 ##' @rdname dataset-extract
 ##' @export
@@ -84,13 +87,13 @@ setMethod("[[", c("CrunchDataset", "character"), function (x, i, ..., drop=FALSE
     if (is.na(n)) {
         ## See if the variable in question is hidden
         hvars <- hidden(x)
-        hnames <- findVariables(hvars, key=namekey(x), value=TRUE)
+        hnames <- getIndexSlot(hvars, namekey(x))
         n <- match(i, hnames)
         if (is.na(n)) {
             return(NULL)
         } else {
             ## If so, return it with a warning
-            out <- hidden(x)[[n]]
+            out <- hvars[[n]]
             if (!is.null(out)) {
                 out <- CrunchVariable(out, filter=activeFilter(x))
             }
@@ -169,7 +172,7 @@ setMethod("$", "CrunchDataset", function (x, name) x[[name]])
 ##' vector defining a subset of the rows of \code{x}. For \code{[[}, see
 ##' \code{j} for the as.list column subsetting.
 ##' @param j if character, identifies variables to extract based on their
-##' aliases (by default: set \code{options(crunch.namekey.dataset="name")} 
+##' aliases (by default: set \code{options(crunch.namekey.dataset="name")}
 ##' to use variable names); if numeric or
 ##' logical, extracts variables accordingly. Note that this is the as.list
 ##' extraction, columns of the dataset rather than rows.
@@ -215,7 +218,8 @@ setMethod("[[<-",
 setMethod("[[<-",
     c("CrunchDataset", "character", "missing", "NULL"),
     function (x, i, value) {
-        if (!(i %in% names(x))) {
+        allnames <- getIndexSlot(allVariables(x), namekey(x)) ## Include hidden
+        if (!(i %in% allnames)) {
             message(dQuote(i), " is not a variable; nothing to delete by assigning NULL")
             return(x)
         }
