@@ -4,11 +4,6 @@ rethrow <- function (x) halt(errorMessage(x))
 
 errorMessage <- function (e) attr(e, "condition")$message
 
-updateList <- function (x, y) {
-    x[names(y)] <- y
-    return(x)
-}
-
 ##' Generic List Element Extractor
 ##'
 ##' @param key character naming the key(s) to extract. Can traverse list
@@ -66,28 +61,26 @@ now <- function () strftime(Sys.time(), usetz=TRUE)
 ##' @importFrom httr parse_url build_url
 absoluteURL <- function (urls, base) {
     ## Detect if we have relative urls, and then concatenate if so
-    if (length(urls) && ## if there is anything to munge
-        !any(substr(urls, 1, 4) == "http")) { ## the urls don't start with http
-            base.url <- parse_url(base)
-            urls <- vapply(urls, function (x, b) {
-                b$path <- joinPath(b$path, x)
-                if (is.null(b$scheme)) {
-                    ## If file path and not URL, as in for tests,
-                    ## let's return it relative
-                    return(b$path)
-                }
-                ## Pop off any leading "/" because build_url will add it
-                b$path <- sub("^/", "", b$path)
-                b$query <- NULL ## Catalog query params aren't valid for entities
-                return(build_url(b))
-            }, character(1), b=base.url, USE.NAMES=FALSE)
-        }
+    if (length(urls) && !any(startsWith(urls, "http"))) {
+        base.url <- parse_url(base)
+        urls <- vapply(urls, function (x, b) {
+            b$path <- joinPath(b$path, x)
+            if (is.null(b$scheme)) {
+                ## If file path and not URL, as in for tests,
+                ## let's return it relative
+                return(b$path)
+            }
+            ## Pop off any leading "/" because build_url will add it
+            b$path <- sub("^/", "", b$path)
+            b$query <- NULL ## Catalog query params aren't valid for entities
+            return(build_url(b))
+        }, character(1), b=base.url, USE.NAMES=FALSE)
+    }
     return(urls)
 }
 
 joinPath <- function (base.path, relative.part) {
-    first.char <- substr(relative.part, 1, 1)
-    if (first.char == "/") {
+    if (startsWith(relative.part, "/")) {
         ## This is absolute, relative to the host
         return(relative.part)
     }
@@ -111,9 +104,7 @@ joinPath <- function (base.path, relative.part) {
         }
     }
     out <- paste(u, collapse="/")
-    last.char <- substr(relative.part, nchar(relative.part),
-        nchar(relative.part))
-    if (last.char == "/") {
+    if (endsWith(relative.part, "/")) {
         out <- paste0(out, "/")
     }
     return(out)
@@ -135,10 +126,33 @@ askForPermission <- function (prompt="") {
     return(proceed == "y")
 }
 
-emptyObject <- function () {
+emptyObject <- function (...) {
     ## toJSON(list()) is "[]". toJSON(emptyObject()) is "{}"
+    ##
+    ## Make the function take ... so you can *apply over something and just
+    ## call the function
     structure(list(), .Names=character(0))
 }
 
+null <- function (...) NULL
+
 ## Borrowed from Hadley
 "%||%" <- function (a, b) if (!is.null(a)) a else b
+
+
+## from future import ...
+basefuns <- ls(envir=asNamespace("base"))
+alt.startsWith <- function (x, prefix) {
+    substr(x, 1, nchar(prefix)) == prefix
+}
+if (!("startsWith" %in% basefuns)) {
+    startsWith <- alt.startsWith
+}
+
+alt.endsWith <- function (x, suffix) {
+    z <- nchar(x)
+    substr(x, z - nchar(suffix) + 1, z) == suffix
+}
+if (!("endsWith" %in% basefuns)) {
+    endsWith <- alt.endsWith
+}
