@@ -43,6 +43,7 @@ newDatasetByColumn <- function (x, name=as.character(substitute(x)), ...) {
     vardefs <- lapply(names(x),
         function (v) toVariable(x[[v]], name=v, alias=v))
     ds <- addVariables(ds, vardefs)
+    saveVersion(ds, "initial import")
     invisible(ds)
 }
 
@@ -190,7 +191,7 @@ createWithMetadataAndFile <- function (metadata, file, strict=TRUE, cleanup=TRUE
     if (!strict) {
         batches_url <- paste0(batches_url, "?strict=0")
     }
-    if (substr(file, 1, 5) == "s3://") {
+    if (startsWith(file, "s3://")) {
         ## S3 upload
         batch <- try(crPOST(batches_url, body=toJSON(list(
             element="shoji:entity",
