@@ -3,30 +3,21 @@ setMethod("permissions", "CrunchDataset", function (x) {
     return(PermissionCatalog(crGET(perm_url)))
 })
 
-##' @rdname describe-catalog
+##' @rdname is.editor
 ##' @export
-setMethod("emails", "PermissionCatalog", function (x) getIndexSlot(x, "email"))
-
-is.editor <- function (x) {
+setMethod("is.editor", "PermissionCatalog", function (x) {
     out <- vapply(index(x), function (a) {
             isTRUE(a[["dataset_permissions"]][["edit"]])
         }, logical(1), USE.NAMES=FALSE)
-    names(out) <- emails(x)
-    structure(return(out))
-}
+    names(out) <- emails(x) ## Drop this
+    return(out)
+})
 
-userCanEdit <- function (email, dataset) {
-    e <- is.editor(permissions(dataset))
-    return(ifelse(email %in% names(e), e[email], FALSE))
-}
-
-iCanEdit <- function (dataset) {
-    is.editor(permissions(dataset)[userURL()])
-}
-
-userCanView <- function (email, dataset) {
-    email %in% emails(permissions(dataset))
-}
+##' @rdname is.editor
+##' @export
+setMethod("is.editor", "PermissionTuple", function (x) {
+    isTRUE(x[["dataset_permissions"]][["edit"]])
+})
 
 ##' Share a dataset
 ##'
@@ -42,6 +33,7 @@ userCanView <- function (email, dataset) {
 ##' dataset be sent an email informing them of this fact? Default is
 ##' \code{TRUE}.
 ##' @return Invisibly, the dataset.
+##' @seealso \code{\link{unshare}}
 ##' @export
 share <- function (dataset, users, edit=FALSE, notify=TRUE) {
     perms <- permissions(dataset)
@@ -71,6 +63,21 @@ passwordSetURLTemplate <- function () {
     absoluteURL("/password/change/${token}/", getOption("crunch.api"))
 }
 
+##' Revoke a user's access to a dataset
+##'
+##' @param dataset a CrunchDataset
+##' @param users character: email address(es) or URLs of the users or teams to
+##' unshare with.
+##' @return Invisibly, the dataset.
+##' @seealso \code{\link{share}}
+##' @export
+unshare <- function (dataset, users) {
+    stopifnot(is.character(users))
+    payload <- sapply(users, null, simplify=FALSE)
+    crPATCH(shojiURL(dataset, "catalogs", "permissions"), body=toJSON(payload))
+    invisible(dataset)
+}
+
 ## TODO: test and release this
 # shareDataset <- function (x, emails, notify=TRUE) {
 #     ## Share one more more datasets without loading them
