@@ -34,13 +34,7 @@ parse_column <- list(
     },
     datetime=function (col, variable) {
         out <- columnParser("text")(col)
-        if (all(grepl("[0-9]{4}-[0-9]{2}-[0-9]{2}", out))) {
-            ## return Date if resolution >= D
-            return(as.Date(out))
-        } else {
-            ## TODO: use from8601, defined below
-            return(as.POSIXct(out))
-        }
+        return(from8601(out))
     }
 )
 columnParser <- function (vartype, mode=NULL) {
@@ -62,7 +56,8 @@ getValues <- function (x, ...) {
 }
 
 paginatedGET <- function (url, query, offset=0,
-                          limit=getOption("crunch.page.size") %||% 1000) {
+                          limit=getOption("crunch.page.size") %||% 1000,
+                          table=FALSE) {
     ## Paginate the GETting of values. Called both from getValues and in
     ## the as.vector.CrunchExpr method in expressions.R
 
@@ -72,12 +67,22 @@ paginatedGET <- function (url, query, offset=0,
     out <- list()
     keep.going <- TRUE
     i <- 1
+
+    ## Function to determine number of values received, depending on whether
+    ## we have a crunch:table or shoji:view
+    if (table) {
+        len <- function (x) length(x$data$out)
+    } else {
+        len <- length
+    }
     with(temp.option(scipen=15), {
         ## Mess with scipen so that the query string formatter doesn't
         ## convert an offset like 100000 to '1+e05', which server rejects
         while(keep.going) {
+            ## Wrap the GET in a parser function, default no-op, so we can
+            ## get data out of a crunch:table
             out[[i]] <- crGET(url, query=query)
-            if (length(out[[i]]) < limit) {
+            if (len(out[[i]]) < limit) {
                 keep.going <- FALSE
             } else {
                 query$offset <- query$offset + limit
@@ -85,7 +90,16 @@ paginatedGET <- function (url, query, offset=0,
             }
         }
     })
-    return(unlist(out, recursive=FALSE))
+
+    ## Collect the result
+    if (table) {
+        out[[1]]$data$out <- unlist(lapply(out, function (x) x$data$out),
+            recursive=FALSE)
+        out <- out[[1]]
+    } else {
+        out <- unlist(out, recursive=FALSE)
+    }
+    return(out)
 }
 
 ##' Convert Variables to local R objects
@@ -114,11 +128,19 @@ setMethod("as.vector", "CrunchVariable", function (x, mode) {
 from8601 <- function (x) {
     ## Crunch timestamps look like "2015-02-12T10:28:05.632000+00:00"
 
-    ## TODO: pull out the ms, as.numeric them, and add to the parsed date
-    ## Important for the round trip of datetime data
+    if (all(grepl("^[0-9]{4}-[0-9]{2}-[0-9]{2}$", na.omit(x)))) {
+        ## return Date if resolution == D
+        return(as.Date(x))
+    }
 
-    ## First, strip out ms and the : in the time zone
-    x <- sub("\\.[0-9]+", "", sub("^(.*[+-][0-9]{2}):([0-9]{2})$", "\\1\\2", x))
+    ## Check for timezone
+    if (any(grepl("+", x, fixed=TRUE))) {
+        ## First, strip out the : in the time zone
+        x <- sub("^(.*[+-][0-9]{2}):([0-9]{2})$", "\\1\\2", x)
+        pattern <- "%Y-%m-%dT%H:%M:%OS%z"
+    } else {
+        pattern <- "%Y-%m-%dT%H:%M:%OS"
+    }
     ## Then parse
-    return(strptime(x, "%Y-%m-%dT%H:%M:%S%z"))
+    return(strptime(x, pattern, tz="UTC"))
 }
