@@ -6,11 +6,6 @@ r2zcl <- function (x) {
     v <- toVariable(x)
     attributes(v$values) <- NULL
 
-    ## Grab any "typeof" attribute that's been attached. This is so we can
-    ## assert that the type we're sending matches the type of some other
-    ## variable, usually another variable in our CrunchExpr
-    zztype <- attr(x, "typeof")
-
     ## If there is a single value, call it "value". Else it is a "column" array
     if (length(x) == 1) {
         out <- list(value=v$values)
@@ -18,12 +13,6 @@ r2zcl <- function (x) {
         out <- list(column=v$values)
     }
 
-    ## Add type information since we have it, so that ZZ9 doesn't have to guess
-    if (!is.null(zztype)) {
-        out$type <- zztype
-    } else {
-        out$type <- list(value=list(class=v$type))
-    }
     return(out)
 }
 
@@ -46,17 +35,6 @@ setMethod("zcl", "zcl", function (x) x)
 setMethod("zcl", "list", function (x) x) ## is this a good idea?
 setMethod("zcl", "CrunchFilter", function (x) x@body$expression)
 
-typeof <- function (x, variable) {
-    ## Add ZCL metadata asserting that x is the same type as variable
-    if (is.character(variable)) {
-        variable <- list(class=variable)
-    } else if (is.variable(variable) || inherits(variable, "VariableTuple")) {
-        variable <- zfunc("typeof", variable)
-    }
-    attr(x, "typeof") <- variable
-    return(x)
-}
-
 zfunc <- function (func, ...) {
     ## Wrapper that creates ZCL function syntax
     return(list(`function`=func, args=lapply(list(...), zcl)))
