@@ -63,7 +63,7 @@ with_mock_HTTP({
 })
 
 if (run.integration.tests) {
-    with(test.authentication, {
+    with_test_authentication({
         with(test.dataset(newDatasetFromFixture("apidocs")), {
             test_that("We can create a new MR by combining", {
                 ds$combined_allpets <- combine(ds$allpets, name="All pets (combined)",
