@@ -5,7 +5,7 @@ test_that("Enter and exit are run", {
     tester <- ContextManager(function () a <<- FALSE,
         function () a <<- TRUE)
 
-    expect_true(is.null(a))
+    expect_null(a)
     with(tester, {
         expect_false(is.null(a))
         expect_false(a)
@@ -20,7 +20,7 @@ test_that("An error in the code being executed is thrown but exit still runs", {
     tester <- ContextManager(function () a <<- FALSE,
         function () a <<- TRUE)
 
-    expect_true(is.null(a))
+    expect_null(a)
     expect_error(with(tester, {
         halt("Testing error handling")
     }), "Testing error handling")
@@ -33,7 +33,7 @@ test_that("Custom error handlers", {
         function () a <<- TRUE,
         error=function (e) halt("Custom error"))
 
-    expect_true(is.null(a))
+    expect_null(a)
     expect_error(with(tester, {
         halt("Testing error handling")
     }), "Custom error")
@@ -70,14 +70,14 @@ test_that("'as' specified in the context manager itself", {
 test_that("temp.options", {
     options(crunch.test.option.test="foo")
     expect_identical(getOption("crunch.test.option.test"), "foo")
-    expect_identical(getOption("crunch.test.test.test.test"), NULL)
+    expect_null(getOption("crunch.test.test.test.test"))
     with(temp.options(crunch.test.option.test="bar",
                      crunch.test.test.test.test="test"), {
         expect_identical(getOption("crunch.test.option.test"), "bar")
         expect_identical(getOption("crunch.test.test.test.test"), "test")
     })
     expect_identical(getOption("crunch.test.option.test"), "foo")
-    expect_identical(getOption("crunch.test.test.test.test"), NULL)
+    expect_null(getOption("crunch.test.test.test.test"))
 })
 
 test_that("consent", {
