@@ -5,17 +5,17 @@ test_that("show method exists", {
 })
 
 if (run.integration.tests) {
-    with(test.authentication, {
+    with_test_authentication({
         with(test.dataset(df), {
             test_that("We have an empty filter catalog", {
-                expect_true(inherits(filters(ds), "FilterCatalog"))
-                expect_identical(length(filters(ds)), 0L)
+                expect_is(filters(ds), "FilterCatalog")
+                expect_length(filters(ds), 0)
                 expect_output(filters(ds), capture.output(print(data.frame())))
             })
 
             filters(ds)[["Test filter"]] <- ds$v4 == "B"
             test_that("We can create a filter", {
-                expect_identical(length(filters(ds)), 1L)
+                expect_length(filters(ds), 1)
                 expect_identical(names(filters(ds)), "Test filter")
                 expect_identical(name(filters(ds)[[1]]), "Test filter")
             })
@@ -28,7 +28,7 @@ if (run.integration.tests) {
                         ))), collapse="\n"), fixed=TRUE)
                 expect_output(filters(ds)[["Test filter"]],
                     paste0('Crunch filter ', dQuote("Test filter"),
-                        '\nExpression: v4 == "B"'))
+                        '\nExpression: v4 == 1L'))
             })
 
             test_that("We can make it public/private", {
@@ -67,21 +67,21 @@ if (run.integration.tests) {
             })
 
             test_that("We have an applied filters view", {
-                expect_identical(length(appliedFilters(ds)), 0L)
+                expect_length(appliedFilters(ds), 0)
             })
 
             test_that("We can 'apply' a filter", {
                 appliedFilters(ds) <- filters(ds)[["Test filter"]]
-                expect_identical(length(appliedFilters(ds)), 1L)
+                expect_length(appliedFilters(ds), 1)
             })
 
             test_that("'applied filters' for the UI don't affect R", {
-                expect_identical(length(appliedFilters(ds)), 1L)
+                expect_length(appliedFilters(ds), 1)
                 validImport(ds)
             })
 
             test_that("We also have 'active filter' for the R object", {
-                expect_identical(activeFilter(ds), NULL)
+                expect_null(activeFilter(ds))
             })
 
             test_that("We can set 'active filter'", {
