@@ -1,21 +1,51 @@
 context("Hiding variables")
 
+with_mock_HTTP({
+    ds <- loadDataset("ECON.sav")
+    test_that("hiddenVariables", {
+        expect_identical(hiddenVariables(ds), "Birth Year")
+        expect_identical(hiddenVariables(ds, "alias"), "birthyr")
+    })
+
+    test_that("Can subset dataset with hidden variable by name/alias", {
+        ds_sub <- ds[c("gender", "birthyr")]
+        expect_identical(names(ds_sub), "gender")
+        expect_identical(aliases(allVariables(ds_sub)), c("gender", "birthyr"))
+    })
+
+    test_that("Can delete a hidden variable", {
+        ## Circumvent the try-catch inside deleteVariables
+        with_mock(try=function (expr, silent) force(expr), eval.parent({
+            expect_message(
+                expect_error(ds$birthyr <- NULL,
+                    "DELETE /api/datasets/dataset3/variables/birthyr.json"),
+                NA)
+            expect_message(
+                expect_error(deleteVariables(ds, "birthyr"),
+                    "DELETE /api/datasets/dataset3/variables/birthyr.json"),
+                NA)
+        }))
+        skip_on_jenkins("No idea why this fails to catch the warning on Jenkins but not on Travis or locally")
+        expect_warning(
+            expect_error(delete(ds$birthyr),
+                "DELETE /api/datasets/dataset3/variables/birthyr.json"),
+            "Variable birthyr is hidden")
+    })
+})
+
 if (run.integration.tests) {
-    with(test.authentication, {
+    with_test_authentication({
         with(test.dataset(df), {
             var1 <- ds[[1]]
             test_that("Hide and unhide method for variables", {
-                expect_true(name(var1) %in% findVariables(ds, key="name",
-                    value=TRUE))
+                expect_true(name(var1) %in% names(variables(ds)))
                 var1 <- hide(var1)
                 ds <- refresh(ds)
-                expect_false(name(var1) %in% findVariables(ds, key="name",
-                    value=TRUE))
+                expect_false(name(var1) %in% names(variables(ds)))
 
                 var1 <- unhide(var1)
                 ds <- refresh(ds)
-                expect_true(name(var1) %in% findVariables(ds, key="name",
-                    value=TRUE))
+                expect_true(name(var1) %in% names(variables(ds)))
             })
         })
 
@@ -30,8 +60,8 @@ if (run.integration.tests) {
             test_that("hideVariables hides by alias", {
                 expect_identical(names(ds)[1:2], c("v1", "v4"))
                 expect_identical(hiddenVariables(ds), c("v2", "v3"))
-                expect_identical(length(hidden(ds)), 2L)
-                expect_identical(length(variables(ds)), ncol(df) - 2L)
+                expect_length(hidden(ds), 2)
+                expect_length(variables(ds), ncol(df) - 2)
                 expect_identical(dim(ds), c(nrow(df), ncol(df) - 2L))
             })
 
@@ -47,12 +77,12 @@ if (run.integration.tests) {
             test_that("hiddenVariables<- adds variables", {
                 expect_identical(names(ds)[1:2], c("v1", "v5"))
                 expect_identical(hiddenVariables(ds), c("v2", "v3", "v4"))
-                expect_identical(dim(ds), c(nrow(df), ncol(df)-3L))
+                expect_identical(dim(ds), c(nrow(df), ncol(df) - 3L))
             })
 
             test_that("hidden variables can be accessed with $", {
-                expect_warning(ds$v2, "hidden")
-                expect_true(is.Text(suppressWarnings(ds$v2)))
+                expect_warning(z <- ds$v2, "hidden")
+                expect_true(is.Text(z))
             })
 
             try(ds <- unhideVariables(ds, c("v2", "v3", "v4")))
@@ -66,18 +96,18 @@ if (run.integration.tests) {
         })
 
         with(test.dataset(df), {
-            test_that("hideVariables with grep (and by index)", {
-                ds <- hideVariables(ds, pattern="v[23]")
+            test_that("hideVariables with grep is deprecated (and by index)", {
+                ds <- hideVariables(ds, c(2, 3))
                 expect_identical(names(ds)[1:2], c("v1", "v4"))
 
-                ds <- unhideVariables(ds, pattern="v[23]")
+                expect_warning(ds <- unhideVariables(ds, pattern="v[23]"),
+                    "Deprecation warning")
                 expect_identical(hiddenVariables(ds), c())
             })
 
             test_that("Error handling", {
                 expect_identical(hiddenVariables(ds), c()) # To be clear
                 ## Need something better than subscript out of bounds, probably
-
             })
         })
 
@@ -87,9 +117,9 @@ if (run.integration.tests) {
                     VariableGroup(name="g1", variables=list(ds$v1)),
                     VariableGroup(name="group2", variables=ds[c("v3", "v4")])
                 )
-                expect_identical(length(grouped(ordering(ds))), 2L)
+                expect_length(grouped(ordering(ds)), 2)
                 ds <- hideVariables(ds, ungrouped(ordering(ds)))
-                expect_identical(length(hiddenVariables(ds)), ncol(df) - 3L)
+                expect_length(hiddenVariables(ds), ncol(df) - 3)
                 expect_true(all(c("v2", "v5") %in% hiddenVariables(ds)))
             })
         })
@@ -115,7 +145,7 @@ if (run.integration.tests) {
             ds <- mrdf.setup(ds, pattern="mr_1")
             test_that("Can hide array variables even if they only have one subvar", {
                 expect_identical(names(ds), c("CA", "mr_2", "mr_3", "v4"))
-                expect_identical(length(subvariables(ds$CA)), 1L)
+                expect_length(subvariables(ds$CA), 1)
                 try(hiddenVariables(ds) <- "CA")
                 expect_false("CA" %in% names(ds))
             })
