@@ -5,8 +5,7 @@ with_mock_HTTP({
     varblob <- crGET(variables.catalog.url)
 
     test_that("VariableCatalog instantiates from Shoji", {
-        expect_true(inherits(VariableCatalog(varblob),
-            "VariableCatalog"))
+        expect_is(VariableCatalog(varblob), "VariableCatalog")
     })
 
     varcat <- VariableCatalog(varblob)
@@ -30,25 +29,25 @@ with_mock_HTTP({
             index(varcat)[urls(ordering(varcat))])
         expect_equivalent(index(hidden(varcat)), list())
         index(varcat)[[2]]$discarded <- TRUE
-        expect_true(inherits(active(varcat), "VariableCatalog"))
-        expect_true(inherits(hidden(varcat), "VariableCatalog"))
+        expect_is(active(varcat), "VariableCatalog")
+        expect_is(hidden(varcat), "VariableCatalog")
         expect_identical(urls(active(varcat)),
             c("/api/datasets/dataset1/variables/gender.json",
             "/api/datasets/dataset1/variables/mymrset.json",
             "/api/datasets/dataset1/variables/textVar.json",
             "/api/datasets/dataset1/variables/starttime.json",
             "/api/datasets/dataset1/variables/catarray.json"))
-        expect_identical(length(active(varcat)), 5L)
+        expect_length(active(varcat), 5)
         expect_identical(urls(hidden(varcat)),
             "/api/datasets/dataset1/variables/birthyr.json")
-        expect_identical(length(hidden(varcat)), 1L)
-        expect_identical(length(varcat), 6L)
+        expect_length(hidden(varcat), 1)
+        expect_length(varcat, 6)
         expect_identical(active(hidden(varcat)), hidden(active(varcat)))
     })
 
     gender.url <- "/api/datasets/dataset1/variables/gender.json"
     test_that("Extract methods: character and numeric", {
-        expect_true(inherits(varcat[[gender.url]], "VariableTuple"))
+        expect_is(varcat[[gender.url]], "VariableTuple")
         expect_identical(varcat[[gender.url]]@body,
             index(varcat)[[gender.url]])
         expect_identical(index(varcat[2:3]), index(varcat)[2:3])
@@ -96,7 +95,7 @@ with_mock_HTTP({
 })
 
 if (run.integration.tests) {
-    with(test.authentication, {
+    with_test_authentication({
         with(test.dataset(df), {
             test_that("Can set descriptions (and doing so doesn't PUT order)", {
                 with(temp.options(httpcache.log=""), {
@@ -106,7 +105,7 @@ if (run.integration.tests) {
                     expect_identical(descriptions(variables(ds))[1:4],
                         c("", "Des 1", "Des 2", ""))
                 })
-                expect_identical(length(logs), 2L) ## PATCH, DROP
+                expect_length(logs, 2) ## PATCH, DROP
             })
             test_that("Can set names and aliases", {
                 n <- names(df)
@@ -137,5 +136,19 @@ if (run.integration.tests) {
                     c("2", "3"))
             })
         })
+
+        with(test.dataset(newDatasetFromFixture("apidocs")), {
+            test_that("variableMetadata", {
+                vm <- variableMetadata(ds)
+                expect_is(vm, "VariableCatalog")
+                i <- which(aliases(vm) == "allpets")
+                expect_identical(Categories(data=vm[[i]]$categories),
+                    categories(ds$allpets))
+                expect_identical(vm[[i]]$subvariables,
+                    subvariables(tuple(ds$allpets)))
+                expect_true(all(grepl("^http", urls(vm))))
+                expect_true(!any(is.na(getIndexSlot(vm, "id"))))
+            })
+        })
     })
 }
