@@ -3,11 +3,11 @@ context("Versions")
 with_mock_HTTP({
     ds <- loadDataset("test ds")
     test_that("Version catalog exists", {
-        expect_true(inherits(versions(ds), "VersionCatalog"))
+        expect_is(versions(ds), "VersionCatalog")
     })
 
     test_that("Version catalog attributes (and sorting)", {
-        expect_identical(length(versions(ds)), 2L)
+        expect_length(versions(ds), 2)
         expect_identical(names(versions(ds)),
             c("another version", "initial load"))
         expect_identical(descriptions(versions(ds)),
@@ -29,6 +29,20 @@ with_mock_HTTP({
             'POST /api/datasets/dataset1/savepoints.json \\{"description":"Today"\\}')
     })
 
+    test_that("saveVersion with no description supplied", {
+        expect_error(saveVersion(ds),
+            'POST /api/datasets/dataset1/savepoints.json \\{"description":"Version 3"\\}')
+    })
+
+    test_that("saveVersion rejects invalid description", {
+        expect_error(saveVersion(ds, c("Today", "Tomorrow")),
+            paste(dQuote("description"), "must be a length-1 character vector"))
+        expect_error(saveVersion(ds, list()),
+            paste(dQuote("description"), "must be a length-1 character vector"))
+        expect_error(saveVersion(ds, character(0)),
+            paste(dQuote("description"), "must be a length-1 character vector"))
+    })
+
     test_that("restoreVersion makes the right request", {
         expect_error(restoreVersion(ds, "initial load"),
             'POST /api/datasets/dataset1/savepoints/v2/revert/')
@@ -42,7 +56,7 @@ with_mock_HTTP({
 
 
 if (run.integration.tests) {
-    with(test.authentication, {
+    with_test_authentication({
         with(test.dataset(df), {
             test_that("Dataset imported correctly", {
                 validImport(ds)
@@ -53,7 +67,6 @@ if (run.integration.tests) {
 
             test_that("There is an initial version", {
                 expect_identical(names(versions(ds)), "initial import")
-                expect_identical(length(versions(ds)), 1L)
             })
 
             ## Make changes:
@@ -109,7 +122,7 @@ if (run.integration.tests) {
             ## Save a version
             try(saveVersion(ds, "My changes"))
             test_that("There are now two versions", {
-                expect_identical(length(versions(ds)), 2L)
+                expect_length(versions(ds), 2)
                 expect_identical(names(versions(ds))[1], "My changes")
             })
 
@@ -119,7 +132,6 @@ if (run.integration.tests) {
             ## Revert to the first version
             ds <- try(restoreVersion(ds, "initial import"))
             test_that("Restoring restored correctly", {
-                expect_identical(length(versions(ds)), 1L)
                 validImport(ds)
             })
 
@@ -135,12 +147,12 @@ if (run.integration.tests) {
             })
 
             test_that("And now we can add variables again that we added and reverted", {
-                expect_true(is.null(ds$v7))
+                expect_null(ds$v7)
                 ## This would error if "v7" were still lurking somewhere
                 ds$v7 <- ds$v3 - 7
                 expect_identical(as.vector(ds$v7), df$v3 - 7)
 
-                expect_true(is.null(ds$v8))
+                expect_null(ds$v8)
                 ds$v8 <- rep(6:10, 4)
                 expect_equivalent(as.vector(ds$v8), rep(6:10, 4))
             })
